@@ -33,7 +33,7 @@ import Language.C.System.Preprocess
 --
 --   > Synopsis: parseCFile preprocesssor tmp-dir? cpp-opts file
 --   > Example:  parseCFile (newGCC "gcc") Nothing ["-I/usr/include/gtk-2.0"] my-gtk-exts.c
-parseCFile :: (Preprocessor cpp) => cpp -> (Maybe FilePath) -> [String] -> FilePath -> IO (Either ParseError CTranslUnit)
+parseCFile :: (Preprocessor cpp) => cpp -> Maybe FilePath -> [String] -> FilePath -> IO (Either ParseError CTranslUnit)
 parseCFile cpp tmp_dir_opt args input_file = do
     input_stream <- if not (isPreprocessed input_file)
                         then  let cpp_args = (rawCppArgs args input_file) { cppTmpDir = tmp_dir_opt }
@@ -50,4 +50,4 @@ parseCFile cpp tmp_dir_opt args input_file = do
 parseCFilePre :: FilePath -> IO (Either ParseError CTranslUnit)
 parseCFilePre file = do
     input_stream <- readInputStream file
-    return $ parseC input_stream (initPos file)
\ No newline at end of file
+    return $ parseC input_stream (initPos file)
